#!/bin/sh

## Clear the slate
rm -f doc/*.texi doc/*.info doc/*.html

## Export `helm.org' to `helm.texi'
emacs -q -batch --file=doc/helm.org --eval '(message "%s: %s" (org-version) (locate-library "ox-texinfo"))' --eval '(org-texinfo-export-to-texinfo)' 

## Note how the inline image is typeset.  The image path has a leading
## dot and the image extension has _no_ dot.  Empirically, the former
## is a problem, but the latter _may_ spring surprises.
cat doc/helm.texi | grep @image

## Convert 'helm.texi' to 'helm.info' and 'helm.html'
makeinfo --no-split doc/helm.texi -o doc/helm.info
makeinfo --html --no-split -o doc/helm.html doc/helm.texi

## Copy `helm.texi' to `helm-1.texi' with some edits.  Strip the
## leading `.' in inline image.  Export this file to `helm-1.info' and
## `helm-1.html'.
sed  's/\.\///' doc/helm.texi > doc/helm-1.texi

## Inspect how the inline image is typeset
cat doc/helm-1.texi | grep @image

makeinfo --no-split doc/helm-1.texi -o doc/helm-1.info
makeinfo --html --no-split -o doc/helm-1.html doc/helm-1.texi

## Now view both the info files in Emacs: (a) C-u C-h i doc/helm.info
## and (b) C-u C-h doc/helm-1.info.  The former does _not_ display the
## image.  But the latter does.  This behaviour is the same when the
## info files (and figures) are `install-info'-ed.
##
## Observation 1: according to
##
##     (info "(texinfo) Image Syntax")
##
## Here is the synopsis of the '@image' command:
##      @image{FILENAME[, WIDTH[, HEIGHT[, ALTTEXT[, EXTENSION]]]]}
##
## For Info and HTML output, 'makeinfo' uses the optional fifth
## argument EXTENSION to '@image' for the filename extension, if it is
## specified and the file is found.  Any leading period should be
## included in EXTENSION.  For example:
##
##      @image{foo,,,,.xpm}
##
##
## So, just to be on the safe side, it would be a good idea to add a dot to
## the image extension.
##
## Observation 2: Why is the caption getting stripped in the output file?
##
## Observaion 3: Anyway to take care of the warnings that texi2html
## generates.  Can the CAPTION text be used as an alt text, when there
## is no alt text?
##
##    doc/helm.texi:37: warning: could not find @image file `./helm-figures/helm-M-x.txt' nor alternate text
##    doc/helm.texi:37: warning: @image file `./helm-figures/helm-M-x' (for HTML) not found, using `./helm-figures/helm-M-x.png'
